@@ -1,6 +1,6 @@
 import logging
 import traceback
-from djraphql.util.django_models import get_field_by_name
+from djraphql.django_models import get_field_by_name
 from six import iteritems
 from ..mappings import Types
 from ...abstract_type_builder import CacheableTypeBuilder
@@ -77,6 +77,8 @@ def build_insert_mutation_resolver(model_class, registry):
             accumulator,
         )
 
+        entity_class.after_insert(instance, info.context)
+
         return mutation_class(
             success=True,
             pks_to_tags=accumulator.pks_to_tags,
@@ -109,7 +111,13 @@ def _partition_relation_operations(data, context, model_class, registry):
 
                 # Otherwise, check that the filter_backend actually includes the referenced object
                 related_entity_class = registry.get_entity_class(field.related_model)
-                related_entity_class.get_queryset(context).get(pk=data[name_with_id])
+                assert (
+                    related_entity_class.get_queryset(context)
+                    .filter(pk=data[name_with_id])
+                    .exists()
+                ), "{} matching query does not exist.".format(
+                    field.related_model.__name__
+                )
             else:
                 pre_save_rel_inputs[field] = data.pop(field.name)
         else:
