@@ -1,6 +1,6 @@
 import logging
 import traceback
-from djraphql.util.django_models import get_pk_fields_for_model, get_field_by_name
+from djraphql.django_models import get_pk_fields_for_model, get_field_by_name
 from .by_pk import build_by_pk_resolver
 from six import iteritems
 from ..mappings import Types
@@ -199,9 +199,14 @@ def _partition_relation_operations(data, model_class, instance, info, registry):
                     )
                 elif name_with_id in data and data[name_with_id] is not None:
                     # Check that the filter_backend actually includes the referenced object.
-                    registry.get_entity_class(field.related_model).get_queryset(
-                        info.context
-                    ).get(pk=data[name_with_id])
+                    assert (
+                        registry.get_entity_class(field.related_model)
+                        .get_queryset(info.context)
+                        .filter(pk=data[name_with_id])
+                        .exists()
+                    ), "{} matching query does not exist.".format(
+                        field.related_model.__name__
+                    )
 
     return pre_save_rel_inputs, post_save_rel_inputs
 
@@ -214,7 +219,23 @@ def _get_object_to_update(data, model_class, entity_class, info, registry):
         pk_search_kwargs = {pk_fields[0].name: data["pk"]}
     else:
         pk_search_kwargs = {field.name: data[field.name] for field in pk_fields}
-    return entity_class.get_queryset(info.context).get(**pk_search_kwargs)
+
+    # Fetch the instance by just its PK first, without any filtering from the
+    # Entity class's filter_backend, which can result in multiple (duplicate)
+    # objects being returned, whereas we always only want just one instance.
+    # This was previously causing unnecessary errors during resolution, e.g.
+    # ".get() returned more than 1, it returned 2!"
+    instance = model_class.objects.get(**pk_search_kwargs)
+
+    # Then, do the check against the Entity class's filter_backend.
+    # This ensures we can only update/reference objects our filter_backend
+    # has access to. Multiple (duplicate) objects can be returned by this query,
+    # we only care that something is returned.
+    assert (
+        entity_class.get_queryset(info.context).filter(pk=instance.pk).exists()
+    ), "{} matching query does not exist.".format(model_class.__name__)
+
+    return instance
 
 
 def perform_nested_list_update(
