@@ -16,7 +16,7 @@ class OrderClause(CacheableTypeBuilder, AbstractTypeBuilder):
         entity_class = registry.get_entity_class(model_class)
 
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
             if not field.concrete:
                 continue
 
